;; Generated package description from fontaine.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "fontaine" "3.0.0.0.20250220.111012" "Set font configurations using presets" '((emacs "29.1")) :commit "fe78a2be64b09f55748fa0c6e62d59e787b761b4" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/fontaine")
